@@ -81,8 +81,14 @@ public:
 	int  get_smeter();
 //	int  get_swr();
 	int  get_power_out();
+
 	double get_power_control();
-	
+//	void get_pc_min_max_step(double &, double &, double &) {
+	void get_pc_min_max_step(double &min, double &max, double &step) {
+		min = 10; max = 100; step = 1; }  // wbx4
+
+	void set_power_control(double val);
+
 	void set_volume_control(int val);
 	int  get_volume_control();
 
@@ -91,18 +97,12 @@ public:
 	void get_squelch_min_max_step (int &min, int &max, int &step) {
 		min = 0; max = 100; step = 1; } 
 
-	void set_power_control(double val);
 	void set_PTT_control(int val);
 	void tune_rig();
 
 	int  next_attenuator();
 	void set_attenuator(int val);
 	int  get_attenuator();
-//	void set_preamp(int val);
-//	int  get_preamp();
-
-//	const char * PRE_label();
-	const char * ATT_label();
 
 	void set_if_shift(int val);
 	bool get_if_shift(int &val);
