@@ -56,13 +56,15 @@ status progStatus = {
 	600,		// int memW;
 	164,		// int memH;
 
-    785,        // int metersX;
-    50,         // int metersy;
-    false,		// bool meters_dialog_visible;
+	785,        // int metersX;
+	50,         // int metersy;
+	false,		// bool meters_dialog_visible;
 
 	20,			// int ddX;
 	20,			// int ddY;
 
+	"default",	// std::string ui_name
+
 	"NONE",		// std::string xcvr_serial_port;
 	0,			// int serial_baudrate;
 	2,			// int stopbits;
@@ -137,8 +139,8 @@ status progStatus = {
 	1,			// poll_compression;
 	1,			// poll_tuner;
 	1,			// poll_ptt;
-	4,			// poll_break_in;
-	4,			// int	poll_all;
+	1,			// poll_break_in;
+	1,			// int	poll_all;
 
 	-1,			// int  iBW_A;
 	1,			// int  imode_A;
@@ -154,6 +156,8 @@ status progStatus = {
 
 	false,		// bool spkr_on;
 	20,			// int  volume;
+	20,			// int  volume_A;
+	20,			// int  volume_B;
 	0,			// double  power_level;
 	100,		// double power_limit;
 	false,		// bool enable_power_limit
@@ -162,17 +166,26 @@ status progStatus = {
 	0,			// int  notch_val;
 	false,		// bool shift;
 	0,			// int  shift_val;
+	false,		// bool shift_A;
+	0,			// int  shift_val_A;
+	false,		// bool shift_B;
+	0,			// int  shift_val_B;
 	0,			// bool pbt_lock;
 	0,			// int  pbt_inner;
 	0,			// int  pbt_outer;
 	100,		// int  rfgain;
-	10,			// int  squelch;
+	100,		// int  rfgain_A;
+	100,		// int  rfgain_B;
+	0,			// int  squelch;
+	0,			// int  squelch_A;
+	0,			// int  squelch_B;
 
 	0,			// int  schema;
 	0,			// int	embed_tabs;
 	0,			// int	show_tabs;
 	true,       // bool first_use;			true only during program start
 	"",			// std::string visible_tab;
+
 	true,		// bool hrd_buttons
 	FL_WHEN_CHANGED,	// int sliders_button
 
@@ -214,7 +227,8 @@ status progStatus = {
 	4,			// int rx_peak;
 	1,			// int pwr_avg;
 	4,			// int pwr_peak;
-	4,			// int pwr_scale ==> Autoselect
+	9,			// int pwr_scale ==> Autoselect
+	4,			// int idd_scale ==> Autoselect
 
 	1,			// bool sync_clock
 	1,			// bool sync_gmt
@@ -246,6 +260,7 @@ status progStatus = {
 	true,		// bool	restore_comp_on_off;
 	true,		// bool	restore_comp_level;
 
+//============= transceiver specific prameters
 //tt550 controls
 	80,			// tt550_line_out;
 	1,			// tt550_agc_level;
@@ -279,6 +294,7 @@ status progStatus = {
 	false,		// tt550_use_xmt_bw;
 
 	25,			// tt550_AM_level;
+
 	0,			// tt550_encoder_step;
 	1,			// tt550_encoder_sensitivity;
 	2000,		// tt550_keypad_timeout;
@@ -312,165 +328,127 @@ status progStatus = {
 // =========================
 	"cmd 1",		// std::string	label1;
 	"",				// std::string	command1;
+	0,				// bool expect...
 	"",				// std::string	shftcmd1;
 	"cmd 2",		// std::string	label2;
 	"",				// std::string	command2;
+	0,				// bool expect...
 	"",				// std::string	shftcmd2;
 	"cmd 3",		// std::string	label3;
 	"",				// std::string	command3;
+	0,				// bool expect...
 	"",				// std::string	shftcmd3;
 	"cmd 4",		// std::string	label4;
 	"", 			// std::string	command4;
+	0,				// bool expect...
 	"",				// std::string	shftcmd4;
 	"cmd 5",		// std::string	label5;
 	"",				// std::string	command5;
+	0,				// bool expect...
 	"",				// std::string	shftcmd5;
 	"cmd 6",		// std::string	label6;
 	"",				// std::string	command6;
+	0,				// bool expect...
 	"",				// std::string	shftcmd6;
 	"cmd 7",		// std::string	label7;
 	"",				// std::string	command7;
+	0,				// bool expect...
 	"",				// std::string	shftcmd7;
 	"cmd 8",		// std::string	label8;
 	"",				// std::string	command8;
+	0,				// bool expect...
 	"",				// std::string	shftcmd8;
 
 	"cmd 9",		// std::string	label9;
 	"",				// std::string	command9;
+	0,				// bool expect...
 	"",				// std::string	shftcmd9;
 	"cmd 10",		// std::string	label10;
 	"",				// std::string	command10;
+	0,				// bool expect...
 	"",				// std::string	shftcmd10;
 	"cmd 11",		// std::string	label11;
 	"",				// std::string	command11;
+	0,				// bool expect...
 	"",				// std::string	shftcmd11;
 	"cmd 12",		// std::string	label12;
 	"",				// std::string	command12;
+	0,				// bool expect...
 	"",				// std::string	shftcmd12;
 	"cmd 13",		// std::string	label13;
 	"",				// std::string	command13;
+	0,				// bool expect...
 	"",				// std::string	shftcmd13;
 	"cmd 14",		// std::string	label14;
 	"",				// std::string	command14;
+	0,				// bool expect...
 	"",				// std::string	shftcmd14;
 	"cmd 15",		// std::string	label15;
 	"",				// std::string	command15;
+	0,				// bool expect...
 	"",				// std::string	shftcmd15;
 	"cmd 16",		// std::string	label16;
 	"",				// std::string	command16;
+	0,				// bool expect...
 	"",				// std::string	shftcmd16;
 
 	"cmd 17",		// std::string	label17;
 	"",				// std::string	command17;
+	0,				// bool expect...
 	"",				// std::string	shftcmd17;
 	"cmd 18",		// std::string	label18;
 	"",				// std::string	command18;
+	0,				// bool expect...
 	"",				// std::string	shftcmd18;
 	"cmd 19",		// std::string	label19;
 	"",				// std::string	command19;
+	0,				// bool expect...
 	"",				// std::string	shftcmd19;
 	"cmd 20",		// std::string	label20;
 	"",				// std::string	command20;
+	0,				// bool expect...
 	"",				// std::string	shftcmd20;
 	"cmd 21",		// std::string	label21;
 	"",				// std::string	command21;
+	0,				// bool expect...
 	"",				// std::string	shftcmd21;
 	"cmd 22",		// std::string	label22;
 	"",				// std::string	command22;
+	0,				// bool expect...
 	"",				// std::string	shftcmd22;
 	"cmd 23",		// std::string	label23;
 	"",				// std::string	command23;
+	0,				// bool expect...
 	"",				// std::string	shftcmd23;
 	"cmd 24",		// std::string	label24;
 	"",				// std::string	command24;
+	0,				// bool expect...
 	"",				// std::string	shftcmd24;
 
 	"1",			// std::string	label_on_start1;
 	"",				// std::string	cmd_on_start1;
+
 	"2",			// std::string	label_on_start2;
 	"",				// std::string	cmd_on_start2;
+
 	"3",			// std::string	label_on_start3;
 	"",				// std::string	cmd_on_start3;
+
 	"4",			// std::string	label_on_start4;
 	"",				// std::string	cmd_on_start4;
 
 	"1",			// std::string	label_on_exit1;
 	"",				// std::string	cmd_on_exit1;
+
 	"2",			// std::string	label_on_exit2;
 	"",				// std::string	cmd_on_exit2;
+
 	"3",			// std::string	label_on_exit3;
 	"",				// std::string	cmd_on_exit3;
+
 	"4",			// std::string	label_on_exit4;
 	"",				// std::string	cmd_on_exit4;
 
-// =========================
-
-	232,		// int	 bg_red;
-	255,		// int	 bg_green;
-	232,		// int	 bg_blue;
-
-	0,			// int	 fg_red;
-	0,			// int	 fg_green;
-	0,			// int	 fg_blue;
-
-	148,		// int	swrRed;
-	0,			// int	swrGreen;
-	148,		// int	swrBlue;
-
-	180,		// int	pwrRed;
-	0,			// int	pwrGreen;
-	0,			// int	pwrBlue;
-
-	0,			// int	smeterRed;
-	180,		// int	smeterGreen;
-	0,			//int	smeterBlue;
-
-	255,		// int	peakRed;
-	0,			// int	peakGreen;
-	0,			// int	peakBlue;
-
-	0,			// int	voltRed;
-	0,			// int	voltGreen;
-	255,		// int	voltBlue;
-	0,			// int	display_voltmeter;
-
-	0,			// int	fg_sys_red;
-	0,			// int	fg_sys_green;
-	0,			// int	fg_sys_blue;
-
-	0xc0,		// int	bg_sys_red;
-	0xc0,		// int	bg_sys_green;
-	0xc0,		// int	bg_sys_blue;
-
-	255,		// int	bg2_sys_red;
-	255,		// int	bg2_sys_green;
-	255,		// int	bg2_sys_blue;
-
-	232,		// int		slider_red;
-	255,		// int		slider_green;
-	232,		// int		slider_blue;
-
-	0,			// int		slider_btn_red;
-	0,			// int		slider_btn_green;
-	128,		// int		slider_btn_blue;
-
-	255,		// int		lighted_btn_red;
-	255,		// int		lighted_btn_green;
-	0,			// int		lighted_btn_blue;
-
-	230,		// int		tab_red;
-	230,		// int		tab_green;
-	230,		// int		tab_blue;
-
-	FL_COURIER,	// Fl_Font fontnbr;
-
-	false,		// bool	 tooltips;
-
-	"base",		// std::string ui_scheme
-
-//	"7362",		// std::string server_port
-//	"127.0.0.1",// std::string server_address
-
 	"127.0.0.1", // std::string xmlrig_addr;
 	"12345",	// std::string xmlrig_port;
 	false,		// bool	xmlrpg_rig;
@@ -484,6 +462,7 @@ status progStatus = {
 
 	"40001",	// std::string tci_port
 	"127.0.0.1",// std::string tci address
+
 	10,			// int  tci_center;
 
 	false,		// bool xcvr auto on
@@ -523,6 +502,7 @@ status progStatus = {
 // memory management
 	4,								// Fl_Font	memfontnbr;
 	14,								// int		memfontsize;
+	"FREQ",							// std::string mem_sortby;
 
 // gpio parameters
 	false,		// bool	gpio_ptt;
@@ -595,12 +575,332 @@ status progStatus = {
 	1,			// int fsk_log_dupcheck;
 	0,			// int fsk_log_nbr
 
+	0,			// int	display_voltmeter;
+
+//----------------------------------------------------------------------
+// UI scheme items
+//----------------------------------------------------------------------
+	false,		// bool	ui_changed;
+
+	232,		// int	 bg_red;
+	255,		// int	 bg_green;
+	232,		// int	 bg_blue;
+
+	0,			// int	 fg_red;
+	0,			// int	 fg_green;
+	0,			// int	 fg_blue;
+
+	148,		// int	swrRed;
+	0,			// int	swrGreen;
+	148,		// int	swrBlue;
+
+	180,		// int	pwrRed;
+	0,			// int	pwrGreen;
+	0,			// int	pwrBlue;
+
+	0,			// int	smeterRed;
+	180,		// int	smeterGreen;
+	0,			//int	smeterBlue;
+
+	0,			// int	voltsRed;
+	0,			// int	voltsGreen;
+	255,		// int	voltsBlue;
+
+	128,		// int	iddRed;
+	0,			// int	iddGreen;
+	0,			// int	iddBlue;
+
+	0,			// int	alcRed;
+	0,			// int	alcGreen;
+	255,		// int	alcBlue;
+
+	255,		// int	smeter_peak_red;
+	0,			// int	smeter_peak_green;
+	0,			// int	smeter_peak_blue;
+
+	255,		// int	swr_peak_red;
+	0,			// int	swr_peak_green;
+	0,			// int	swr_peak_blue;
+
+	255,		// int	pwr_peak_red;
+	0,			// int	pwr_peak_green;
+	0,			// int	pwr_peak_blue;
+
+	255,		// int	alc_peak_red;
+	0,			// int	alc_peak_green;
+	0,			// int	alc_peak_blue;
+
+	255,		// int	idd_peak_red;
+	0,			// int	idd_peak_green;
+	0,			// int	idd_peak_blue;
+
+	255,		// int	volts_peak_red;
+	0,			// int	volts_peak_green;
+	0,			// int	volts_peak_blue;
+
+	0,			// int	fg_sys_red;
+	0,			// int	fg_sys_green;
+	0,			// int	fg_sys_blue;
+
+	0xc0,		// int	bg_sys_red;
+	0xc0,		// int	bg_sys_green;
+	0xc0,		// int	bg_sys_blue;
+
+	255,		// int	bg2_sys_red;
+	255,		// int	bg2_sys_green;
+	255,		// int	bg2_sys_blue;
+
+	232,		// int		slider_red;
+	255,		// int		slider_green;
+	232,		// int		slider_blue;
+
+	0,			// int		slider_btn_red;
+	0,			// int		slider_btn_green;
+	128,		// int		slider_btn_blue;
+
+	255,		// int		lighted_btn_red;
+	255,		// int		lighted_btn_green;
+	0,			// int		lighted_btn_blue;
+
+	230,		// int		tab_red;
+	230,		// int		tab_green;
+	230,		// int		tab_blue;
+
+	FL_COURIER,	// Fl_Font fontnbr;
+
+	false,		// bool	 tooltips;
+
+	"base",		// std::string ui_scheme
+//----------------------------------------------------------------------
+
 };
 
+void status::saveScheme(std::string sch_name)
+{
+#if FLRIG_FLTK_API_MINOR < 4
+	Fl_Preferences spref(RigHomeDir.c_str(), "w1hkj.com", sch_name.c_str());
+#else
+	Fl_Preferences spref(
+		RigHomeDir.c_str(),
+		"w1hkj.com",
+		sch_name.c_str(),
+		Fl_Preferences::C_LOCALE);
+#endif
+
+	spref.set("ui_scheme", ui_scheme.c_str());
+
+	spref.set("fontnbr", fontnbr);
+
+	spref.set("fg_red", fg_red);
+	spref.set("fg_green", fg_green);
+	spref.set("fg_blue", fg_blue);
+
+	spref.set("bg_red", bg_red);
+	spref.set("bg_green", bg_green);
+	spref.set("bg_blue", bg_blue);
+
+	spref.set("smeter_red", smeterRed);
+	spref.set("smeter_green", smeterGreen);
+	spref.set("smeter_blue", smeterBlue);
+
+	spref.set("power_red", pwrRed);
+	spref.set("power_green", pwrGreen);
+	spref.set("power_blue", pwrBlue);
+
+	spref.set("swr_red", swrRed);
+	spref.set("swr_green", swrGreen);
+	spref.set("swr_blue", swrBlue);
+
+	spref.set("alc_red", alcRed);
+	spref.set("alc_green", alcGreen);
+	spref.set("alc_blue", alcBlue);
+
+	spref.set("idd_red", iddRed);
+	spref.set("idd_green", iddGreen);
+	spref.set("idd_blue", iddBlue);
+
+	spref.set("volts_red", voltsRed);
+	spref.set("volts_green", voltsGreen);
+	spref.set("volts_blue", voltsBlue);
+
+	spref.set("smeter_peak_red", smeter_peak_red);
+	spref.set("smeter_peak_green", smeter_peak_green);
+	spref.set("smeter_peak_blue", smeter_peak_blue);
+
+	spref.set("pwr_peak_red", pwr_peak_red);
+	spref.set("pwr_peak_green", pwr_peak_green);
+	spref.set("pwr_peak_blue", pwr_peak_blue);
+
+	spref.set("swr_peak_red", swr_peak_red);
+	spref.set("swr_peak_green", swr_peak_green);
+	spref.set("swr_peak_blue", swr_peak_blue);
+
+	spref.set("alc_peak_red", alc_peak_red);
+	spref.set("alc_peak_green", alc_peak_green);
+	spref.set("alc_peak_blue", alc_peak_blue);
+
+	spref.set("idd_peak_red", idd_peak_red);
+	spref.set("idd_peak_green", idd_peak_green);
+	spref.set("idd_peak_blue", idd_peak_blue);
+
+	spref.set("volts_peak_red", volts_peak_red);
+	spref.set("volts_peak_green", volts_peak_green);
+	spref.set("volts_peak_blue", volts_peak_blue);
+
+	spref.set("fg_sys_red", fg_sys_red);
+	spref.set("fg_sys_green", fg_sys_green);
+	spref.set("fg_sys_blue", fg_sys_blue);
+
+	spref.set("bg_sys_red", bg_sys_red);
+	spref.set("bg_sys_green", bg_sys_green);
+	spref.set("bg_sys_blue", bg_sys_blue);
+
+	spref.set("bg2_sys_red", bg2_sys_red);
+	spref.set("bg2_sys_green", bg2_sys_green);
+	spref.set("bg2_sys_blue", bg2_sys_blue);
+
+	spref.set("slider_red", slider_red);
+	spref.set("slider_green", slider_green);
+	spref.set("slider_blue", slider_blue);
+
+	spref.set("slider_btn_red", slider_btn_red);
+	spref.set("slider_btn_green", slider_btn_green);
+	spref.set("slider_btn_blue", slider_btn_blue);
+
+	spref.set("lighted_btn_red", lighted_btn_red);
+	spref.set("lighted_btn_green", lighted_btn_green);
+	spref.set("lighted_btn_blue", lighted_btn_blue);
+
+	spref.set("tab_red", tab_red);
+	spref.set("tab_green", tab_green);
+	spref.set("tab_blue", tab_blue);
+
+}
+
+void status::loadScheme(std::string sch_name)
+{
+#if FLRIG_FLTK_API_MINOR < 4
+	Fl_Preferences spref(RigHomeDir.c_str(), "w1hkj.com", sch_name.c_str());
+#else
+	Fl_Preferences spref(
+		RigHomeDir.c_str(),
+		"w1hkj.com",
+		sch_name.c_str(),
+		Fl_Preferences::C_LOCALE);
+#endif
+
+
+	if (spref.entryExists("ui_scheme")) {
+
+		char defbuffer[MAX_DEFBUFFER_SIZE];
+		spref.get("ui_scheme", defbuffer, "gtk+", MAX_DEFBUFFER_SIZE);
+		ui_scheme = defbuffer;
+
+		int i = (int)fontnbr;
+		spref.get("fontnbr", i, i); fontnbr = (Fl_Font)i;
+		i = 0;
+
+		spref.get("fg_red", fg_red, fg_red);
+		spref.get("fg_green", fg_green, fg_green);
+		spref.get("fg_blue", fg_blue, fg_blue);
+
+		spref.get("bg_red", bg_red, bg_red);
+		spref.get("bg_green", bg_green, bg_green);
+		spref.get("bg_blue", bg_blue, bg_blue);
+
+		spref.get("smeter_red", smeterRed, smeterRed);
+		spref.get("smeter_green", smeterGreen, smeterGreen);
+		spref.get("smeter_blue", smeterBlue, smeterBlue);
+
+		spref.get("power_red", pwrRed, pwrRed);
+		spref.get("power_green", pwrGreen, pwrGreen);
+		spref.get("power_blue", pwrBlue, pwrBlue);
+
+		spref.get("swr_red", swrRed, swrRed);
+		spref.get("swr_green", swrGreen, swrGreen);
+		spref.get("swr_blue", swrBlue, swrBlue);
+
+		spref.get("alc_red", alcRed, alcRed);
+		spref.get("alc_green", alcGreen, alcGreen);
+		spref.get("alc_blue", alcBlue, alcBlue);
+
+		spref.get("idd_red", iddRed, iddRed);
+		spref.get("idd_green", iddGreen, iddGreen);
+		spref.get("idd_blue", iddBlue, iddBlue);
+
+		spref.get("volts_red", voltsRed, voltsRed);
+		spref.get("volts_green", voltsGreen, voltsGreen);
+		spref.get("volts_blue", voltsBlue, voltsBlue);
+
+		spref.get("smeter_peak_red", smeter_peak_red, smeter_peak_red);
+		spref.get("smeter_peak_green", smeter_peak_green, smeter_peak_green);
+		spref.get("smeter_peak_blue", smeter_peak_blue, smeter_peak_blue);
+
+		spref.get("swr_peak_red", swr_peak_red, swr_peak_red);
+		spref.get("swr_peak_green", swr_peak_green, swr_peak_green);
+		spref.get("swr_peak_blue", swr_peak_blue, swr_peak_blue);
+
+		spref.get("pwr_peak_red", pwr_peak_red, pwr_peak_red);
+		spref.get("pwr_peak_green", pwr_peak_green, pwr_peak_green);
+		spref.get("pwr_peak_blue", pwr_peak_blue, pwr_peak_blue);
+
+		spref.get("alc_peak_red", alc_peak_red, alc_peak_red);
+		spref.get("alc_peak_green", alc_peak_green, alc_peak_green);
+		spref.get("alc_peak_blue", alc_peak_blue, alc_peak_blue);
+
+		spref.get("idd_peak_red", idd_peak_red, idd_peak_red);
+		spref.get("idd_peak_green", idd_peak_green, idd_peak_green);
+		spref.get("idd_peak_blue", idd_peak_blue, idd_peak_blue);
+
+		spref.get("volts_peak_red", volts_peak_red, volts_peak_red);
+		spref.get("volts_peak_green", volts_peak_green, volts_peak_green);
+		spref.get("volts_peak_blue", volts_peak_blue, volts_peak_blue);
+
+		spref.get("fg_sys_red", fg_sys_red, fg_sys_red);
+		spref.get("fg_sys_green", fg_sys_green, fg_sys_green);
+		spref.get("fg_sys_blue", fg_sys_blue, fg_sys_blue);
+
+		spref.get("bg_sys_red", bg_sys_red, bg_sys_red);
+		spref.get("bg_sys_green", bg_sys_green, bg_sys_green);
+		spref.get("bg_sys_blue", bg_sys_blue, bg_sys_blue);
+
+		spref.get("bg2_sys_red", bg2_sys_red, bg2_sys_red);
+		spref.get("bg2_sys_green", bg2_sys_green, bg2_sys_green);
+		spref.get("bg2_sys_blue", bg2_sys_blue, bg2_sys_blue);
+
+		spref.get("slider_red", slider_red, slider_red);
+		spref.get("slider_green", slider_green, slider_green);
+		spref.get("slider_blue", slider_blue, slider_blue);
+
+		spref.get("slider_btn_red", slider_btn_red, slider_btn_red);
+		spref.get("slider_btn_green", slider_btn_green, slider_btn_green);
+		spref.get("slider_btn_blue", slider_btn_blue, slider_btn_blue);
+
+		spref.get("lighted_btn_red", lighted_btn_red, lighted_btn_red);
+		spref.get("lighted_btn_green", lighted_btn_green, lighted_btn_green);
+		spref.get("lighted_btn_blue", lighted_btn_blue, lighted_btn_blue);
+
+		spref.get("tab_red", tab_red, tab_red);
+		spref.get("tab_green", tab_green, tab_green);
+		spref.get("tab_blue", tab_blue, tab_blue);
+
+	}
+}
+
 void status::saveLastState()
 {
 	xcvr_name = selrig->name_;
+
+#if FLRIG_FLTK_API_MINOR < 4
 	Fl_Preferences xcvrpref(RigHomeDir.c_str(), "w1hkj.com", PACKAGE_TARNAME);
+#else
+	Fl_Preferences xcvrpref(
+		RigHomeDir.c_str(),
+		"w1hkj.com",
+		PACKAGE_TARNAME,
+		Fl_Preferences::C_LOCALE);
+#endif
+
 	xcvrpref.set("xcvr_name", xcvr_name.c_str());
 
 	int mX = mainwindow->x();
@@ -614,12 +914,12 @@ void status::saveLastState()
 		memW = dlgMemoryDialog->w();
 		memH = dlgMemoryDialog->h();
 	}
-    
-    if (meters_dialog)
-    {
-        metersX = meters_dialog->x();
-        metersY = meters_dialog->y();
-    }
+	
+	if (meters_dialog)
+	{
+		metersX = meters_dialog->x();
+		metersY = meters_dialog->y();
+	}
 
 	mainX = mX;
 	mainY = mY;
@@ -634,7 +934,16 @@ void status::saveLastState()
 	if (tabsGeneric)
 		visible_tab = (tabsGeneric->value())->label();
 
+#if FLRIG_FLTK_API_MINOR < 4
 	Fl_Preferences spref(RigHomeDir.c_str(), "w1hkj.com", xcvr_name.c_str());
+#else
+	Fl_Preferences spref(
+		RigHomeDir.c_str(),
+		"w1hkj.com",
+		xcvr_name.c_str(),
+		Fl_Preferences::C_LOCALE);
+#endif
+
 
 	spref.set("version", PACKAGE_VERSION);
 
@@ -650,13 +959,15 @@ void status::saveLastState()
 	spref.set("memw", memW);
 	spref.set("memh", memH);
 
-    spref.set("metersx", metersX);
-    spref.set("metersy", metersY);
-    spref.set("meters_dialog_visible", meters_dialog->shown());
+	spref.set("metersx", metersX);
+	spref.set("metersy", metersY);
+	spref.set("meters_dialog_visible", meters_dialog->shown());
 
 	spref.set("ddx", ddX);
 	spref.set("ddy", ddY);
 
+	spref.set("ui_name", ui_name.c_str());
+
 	spref.set("xcvr_serial_port", xcvr_serial_port.c_str());
 	spref.set("serial_baudrate", serial_baudrate);
 	spref.set("serial_stopbits", stopbits);
@@ -768,6 +1079,8 @@ void status::saveLastState()
 
 	spref.set("bool_spkr_on", spkr_on);
 	spref.set("int_volume", volume);
+	spref.set("int_volume_A", volume_A);
+	spref.set("int_volume_B", volume_B);
 	spref.set("dbl_power", power_level);
 	spref.set("power_limit", power_limit);
 	spref.set("enable_power_limit", enable_power_limit);
@@ -776,13 +1089,21 @@ void status::saveLastState()
 	spref.set("int_notch", notch_val);
 	spref.set("bool_shift", shift);
 	spref.set("int_shift", shift_val);
+	spref.set("bool_shift_A", shift_A);
+	spref.set("int_shift_A", shift_val_A);
+	spref.set("bool_shift_B", shift_B);
+	spref.set("int_shift_b", shift_val_B);
 
 	spref.set("pbt_lock", pbt_lock);
 	spref.set("pbt_inner", pbt_inner);
 	spref.set("pbt_outer", pbt_outer);
 
 	spref.set("rfgain", rfgain);
+	spref.set("rfgain_A", rfgain_A);
+	spref.set("rfgain_B", rfgain_B);
 	spref.set("squelch", squelch);
+	spref.set("squelch_A", squelch_A);
+	spref.set("squelch_B", squelch_B);
 	spref.set("no_txqsy", no_txqsy);
 
 	spref.set("schema", schema);
@@ -1001,6 +1322,31 @@ void status::saveLastState()
 	spref.set("command24", command24.c_str());
 	spref.set("shftcmd24", shftcmd24.c_str());
 
+	spref.set("expect1", expect1);
+	spref.set("expect2", expect1);
+	spref.set("expect3", expect1);
+	spref.set("expect4", expect1);
+	spref.set("expect5", expect1);
+	spref.set("expect6", expect1);
+	spref.set("expect7", expect1);
+	spref.set("expect8", expect1);
+	spref.set("expect9", expect1);
+	spref.set("expect10", expect1);
+	spref.set("expect11", expect1);
+	spref.set("expect12", expect1);
+	spref.set("expect13", expect1);
+	spref.set("expect14", expect1);
+	spref.set("expect15", expect1);
+	spref.set("expect16", expect1);
+	spref.set("expect17", expect1);
+	spref.set("expect18", expect1);
+	spref.set("expect19", expect1);
+	spref.set("expect20", expect1);
+	spref.set("expect21", expect1);
+	spref.set("expect22", expect1);
+	spref.set("expect23", expect1);
+	spref.set("expect24", expect1);
+
 	spref.set("st_label1", label_on_start1.c_str());
 	spref.set("st_cmd1", cmd_on_start1.c_str());
 
@@ -1025,72 +1371,13 @@ void status::saveLastState()
 	spref.set("ex_label4", label_on_exit4.c_str());
 	spref.set("ex_cmd4", cmd_on_exit4.c_str());
 
-	spref.set("fg_red", fg_red);
-	spref.set("fg_green", fg_green);
-	spref.set("fg_blue", fg_blue);
-
-	spref.set("bg_red", bg_red);
-	spref.set("bg_green", bg_green);
-	spref.set("bg_blue", bg_blue);
-
-	spref.set("smeter_red", smeterRed);
-	spref.set("smeter_green", smeterGreen);
-	spref.set("smeter_blue", smeterBlue);
-
-	spref.set("power_red", pwrRed);
-	spref.set("power_green", pwrGreen);
-	spref.set("power_blue", pwrBlue);
-
-	spref.set("swr_red", swrRed);
-	spref.set("swr_green", swrGreen);
-	spref.set("swr_blue", swrBlue);
-
-	spref.set("peak_red", peakRed);
-	spref.set("peak_green", peakGreen);
-	spref.set("peak_blue", peakBlue);
-
-	spref.set("volt_red", voltRed);
-	spref.set("volt_green", voltGreen);
-	spref.set("volt_blue", voltBlue);
 	spref.set("display_voltmeter", display_voltmeter);
-
-	spref.set("fg_sys_red", fg_sys_red);
-	spref.set("fg_sys_green", fg_sys_green);
-	spref.set("fg_sys_blue", fg_sys_blue);
-
-	spref.set("bg_sys_red", bg_sys_red);
-	spref.set("bg_sys_green", bg_sys_green);
-	spref.set("bg_sys_blue", bg_sys_blue);
-
-	spref.set("bg2_sys_red", bg2_sys_red);
-	spref.set("bg2_sys_green", bg2_sys_green);
-	spref.set("bg2_sys_blue", bg2_sys_blue);
-
-	spref.set("slider_red", slider_red);
-	spref.set("slider_green", slider_green);
-	spref.set("slider_blue", slider_blue);
-
-	spref.set("slider_btn_red", slider_btn_red);
-	spref.set("slider_btn_green", slider_btn_green);
-	spref.set("slider_btn_blue", slider_btn_blue);
-
-	spref.set("lighted_btn_red", lighted_btn_red);
-	spref.set("lighted_btn_green", lighted_btn_green);
-	spref.set("lighted_btn_blue", lighted_btn_blue);
-
-	spref.set("tab_red", tab_red);
-	spref.set("tab_green", tab_green);
-	spref.set("tab_blue", tab_blue);
-
 	spref.set("fontnbr", fontnbr);
 
 	spref.set("tooltips", tooltips);
 
 	spref.set("ui_scheme", ui_scheme.c_str());
 
-//	spref.set("server_port", server_port.c_str());
-//	spref.set("server_addr", server_addr.c_str());
-
 	spref.set("xmlrig_port", xmlrig_port.c_str());
 	spref.set("xmlrig_addr", xmlrig_addr.c_str());
 
@@ -1184,6 +1471,7 @@ void status::saveLastState()
 
 	spref.set("memfontnbr", memfontnbr);
 	spref.set("memfontsize", memfontsize);
+	spref.set("mem_sortby", mem_sortby.c_str());
 
 	spref.set("gpio_ptt", gpio_ptt);
 	spref.set("enable_gpio", enable_gpio);
@@ -1251,11 +1539,21 @@ void status::saveLastState()
 	spref.set("FSK_DUPCHECK", fsk_log_dupcheck);
 	spref.set("FSK_LOG_NBR", fsk_log_nbr);
 
+	saveScheme(ui_name);
 }
 
 bool status::loadXcvrState(std::string xcvr)
 {
+#if FLRIG_FLTK_API_MINOR < 4
 	Fl_Preferences spref(RigHomeDir.c_str(), "w1hkj.com", xcvr.c_str());
+#else
+	Fl_Preferences spref(
+		RigHomeDir.c_str(),
+		"w1hkj.com",
+		xcvr.c_str(),
+		Fl_Preferences::C_LOCALE);
+#endif
+
 
 	if (spref.entryExists("version")) {
 
@@ -1279,9 +1577,9 @@ bool status::loadXcvrState(std::string xcvr)
 		spref.get("memw", memW, memW);
 		spref.get("memh", memH, memH);
 
-        spref.get("metersx", metersX, metersX);
-        spref.get("metersy", metersY, metersY);
-        spref.get("meters_dialog_visible", i, i); meters_dialog_visible = i;
+		spref.get("metersx", metersX, metersX);
+		spref.get("metersy", metersY, metersY);
+		spref.get("meters_dialog_visible", i, i); meters_dialog_visible = i;
 
 		spref.get("ddX", ddX, ddX);
 		spref.get("ddY", ddY, ddY);
@@ -1298,6 +1596,10 @@ bool status::loadXcvrState(std::string xcvr)
 			if (mainW < TOUCH_MAINW) mainW = TOUCH_MAINW;
 		}
 
+		spref.get("ui_name", defbuffer, "default", MAX_DEFBUFFER_SIZE);
+		ui_name = defbuffer;
+
+		memset(defbuffer, 0, MAX_DEFBUFFER_SIZE);
 		spref.get("xcvr_serial_port", defbuffer, "NONE", MAX_DEFBUFFER_SIZE);
 		xcvr_serial_port = defbuffer;
 		if (xcvr_serial_port.find("tty") == 0)
@@ -1444,21 +1746,33 @@ bool status::loadXcvrState(std::string xcvr)
 
 		if (spref.get("bool_spkr_on", i, i)) spkr_on = i;
 		spref.get("int_volume", volume, volume);
+		spref.get("int_volume_A", volume_A, volume_A);
+		spref.get("int_volume_A", volume_B, volume_B);
+
 		spref.get("dbl_power", power_level, power_level);
 		spref.get("power_limit", power_limit, power_limit);
 		if (spref.get("enable_power_limit", i, i)) enable_power_limit = i;
 		spref.get("int_mic", mic_gain, mic_gain);
 		if (spref.get("bool_notch", i, i)) notch = i;
 		spref.get("int_notch", notch_val, notch_val);
+
 		if (spref.get("bool_shift", i, i)) shift = i;
 		spref.get("int_shift", shift_val, shift_val);
+		if (spref.get("bool_shift_A", i, i)) shift_A = i;
+		spref.get("int_shift_A", shift_val_A, shift_val_A);
+		if (spref.get("bool_shift_B", i, i)) shift_B = i;
+		spref.get("int_shift_B", shift_val_B, shift_val_B);
 
 		if (spref.get("pbt_lock", i, pbt_lock)) pbt_lock = i;
 		if (spref.get("pbt_inner", i, pbt_inner)) pbt_inner = i;
 		if (spref.get("pbt_outer", i, pbt_outer)) pbt_outer = i;
 
 		spref.get("rfgain", rfgain, rfgain);
+		spref.get("rfgain_A", rfgain_A, rfgain_A);
+		spref.get("rfgain_B", rfgain_B, rfgain_B);
 		spref.get("squelch", squelch, squelch);
+		spref.get("squelch_A", squelch_A, squelch_A);
+		spref.get("squelch_B", squelch_B, squelch_B);
 		spref.get("no_txqsy", no_txqsy, no_txqsy);
 
 		spref.get("schema", schema, schema);
@@ -1750,6 +2064,31 @@ bool status::loadXcvrState(std::string xcvr)
 		spref.get("shftcmd24", defbuffer, shftcmd24.c_str(), MAX_DEFBUFFER_SIZE);
 		shftcmd24 = defbuffer;
 
+		spref.get("expect1", expect1, expect1);
+		spref.get("expect2", expect2, expect2);
+		spref.get("expect3", expect3, expect3);
+		spref.get("expect4", expect4, expect4);
+		spref.get("expect5", expect5, expect5);
+		spref.get("expect6", expect6, expect6);
+		spref.get("expect7", expect7, expect7);
+		spref.get("expect8", expect8, expect8);
+		spref.get("expect9", expect9, expect9);
+		spref.get("expect10", expect10, expect10);
+		spref.get("expect11", expect12, expect11);
+		spref.get("expect12", expect12, expect12);
+		spref.get("expect13", expect13, expect13);
+		spref.get("expect14", expect14, expect14);
+		spref.get("expect15", expect15, expect15);
+		spref.get("expect16", expect16, expect16);
+		spref.get("expect17", expect17, expect17);
+		spref.get("expect18", expect18, expect18);
+		spref.get("expect19", expect19, expect19);
+		spref.get("expect20", expect20, expect20);
+		spref.get("expect21", expect21, expect21);
+		spref.get("expect22", expect22, expect22);
+		spref.get("expect23", expect23, expect23);
+		spref.get("expect24", expect24, expect24);
+
 		spref.get("st_label1", defbuffer, label_on_start1.c_str(), MAX_DEFBUFFER_SIZE);
 		label_on_start1 = defbuffer;
 		spref.get("st_cmd1", defbuffer, cmd_on_start1.c_str(), MAX_DEFBUFFER_SIZE);
@@ -1790,76 +2129,11 @@ bool status::loadXcvrState(std::string xcvr)
 		spref.get("ex_cmd4", defbuffer, cmd_on_exit4.c_str(), MAX_DEFBUFFER_SIZE);
 		cmd_on_exit4 = defbuffer;
 
-		spref.get("fg_red", fg_red, fg_red);
-		spref.get("fg_green", fg_green, fg_green);
-		spref.get("fg_blue", fg_blue, fg_blue);
-
-		spref.get("bg_red", bg_red, bg_red);
-		spref.get("bg_green", bg_green, bg_green);
-		spref.get("bg_blue", bg_blue, bg_blue);
-
-		spref.get("smeter_red", smeterRed, smeterRed);
-		spref.get("smeter_green", smeterGreen, smeterGreen);
-		spref.get("smeter_blue", smeterBlue, smeterBlue);
-
-		spref.get("power_red", pwrRed, pwrRed);
-		spref.get("power_green", pwrGreen, pwrGreen);
-		spref.get("power_blue", pwrBlue, pwrBlue);
-
-		spref.get("swr_red", swrRed, swrRed);
-		spref.get("swr_green", swrGreen, swrGreen);
-		spref.get("swr_blue", swrBlue, swrBlue);
-
-		spref.get("peak_red", peakRed, peakRed);
-		spref.get("peak_green", peakGreen, peakGreen);
-		spref.get("peak_blue", peakBlue, peakBlue);
-
-		spref.get("volt_red", voltRed, voltRed);
-		spref.get("volt_green", voltGreen, voltGreen);
-		spref.get("volt_blue", voltBlue, voltBlue);
 		spref.get("display_voltmeter", display_voltmeter, display_voltmeter);
 
-		spref.get("fg_sys_red", fg_sys_red, fg_sys_red);
-		spref.get("fg_sys_green", fg_sys_green, fg_sys_green);
-		spref.get("fg_sys_blue", fg_sys_blue, fg_sys_blue);
-
-		spref.get("bg_sys_red", bg_sys_red, bg_sys_red);
-		spref.get("bg_sys_green", bg_sys_green, bg_sys_green);
-		spref.get("bg_sys_blue", bg_sys_blue, bg_sys_blue);
-
-		spref.get("bg2_sys_red", bg2_sys_red, bg2_sys_red);
-		spref.get("bg2_sys_green", bg2_sys_green, bg2_sys_green);
-		spref.get("bg2_sys_blue", bg2_sys_blue, bg2_sys_blue);
-
-		spref.get("slider_red", slider_red, slider_red);
-		spref.get("slider_green", slider_green, slider_green);
-		spref.get("slider_blue", slider_blue, slider_blue);
-
-		spref.get("slider_btn_red", slider_btn_red, slider_btn_red);
-		spref.get("slider_btn_green", slider_btn_green, slider_btn_green);
-		spref.get("slider_btn_blue", slider_btn_blue, slider_btn_blue);
-
-		spref.get("lighted_btn_red", lighted_btn_red, lighted_btn_red);
-		spref.get("lighted_btn_green", lighted_btn_green, lighted_btn_green);
-		spref.get("lighted_btn_blue", lighted_btn_blue, lighted_btn_blue);
-
-		spref.get("tab_red", tab_red, tab_red);
-		spref.get("tab_green", tab_green, tab_green);
-		spref.get("tab_blue", tab_blue, tab_blue);
-
-		i = (int)fontnbr;
-		spref.get("fontnbr", i, i); fontnbr = (Fl_Font)i;
 		i = 0;
 		if (spref.get("tooltips", i, i)) tooltips = i;
 
-		spref.get("ui_scheme", defbuffer, "gtk+", MAX_DEFBUFFER_SIZE);
-		ui_scheme = defbuffer;
-
-//		spref.get("server_port", defbuffer, "7362", MAX_DEFBUFFER_SIZE);
-//		server_port = defbuffer;
-//		spref.get("server_addr", defbuffer, "127.0.0.1", MAX_DEFBUFFER_SIZE);
-//		server_addr = defbuffer;
-
 		spref.get("xmlrig_port", defbuffer, "12345", MAX_DEFBUFFER_SIZE);
 		xmlrig_port = defbuffer;
 		spref.get("xmlrig_addr", defbuffer, "127.0.0.1", MAX_DEFBUFFER_SIZE);
@@ -1971,6 +2245,8 @@ bool status::loadXcvrState(std::string xcvr)
 
 		spref.get("memfontnbr", memfontnbr, memfontnbr);
 		spref.get("memfontsize", memfontsize, memfontsize);
+		spref.get("mem_sortby", defbuffer, mem_sortby.c_str(), MAX_DEFBUFFER_SIZE);
+		mem_sortby = defbuffer;
 
 		if (spref.get("gpio_ptt", i, i)) gpio_ptt = i;
 		spref.get("enable_gpio", enable_gpio, enable_gpio);
@@ -2053,6 +2329,8 @@ bool status::loadXcvrState(std::string xcvr)
 			FSK_msgs[n] = defbuffer;
 		}
 
+		loadScheme(ui_name);
+
 		return true; 
 	}
 	return false;
@@ -2060,7 +2338,16 @@ bool status::loadXcvrState(std::string xcvr)
 
 void status::loadLastState()
 {
+#if FLRIG_FLTK_API_MINOR < 4
 	Fl_Preferences xcvrpref(RigHomeDir.c_str(), "w1hkj.com", PACKAGE_TARNAME);
+#else
+	Fl_Preferences xcvrpref(
+		RigHomeDir.c_str(),
+		"w1hkj.com",
+		PACKAGE_TARNAME,
+		Fl_Preferences::C_LOCALE);
+#endif
+
 	if (xcvrpref.entryExists("xcvr_name")) {
 		char defbuffer[MAX_DEFBUFFER_SIZE];
 		xcvrpref.get("xcvr_name", defbuffer, "NONE", MAX_DEFBUFFER_SIZE);
@@ -2071,20 +2358,25 @@ void status::loadLastState()
 		xcvrpref.get("last_xcvr_used", defbuffer, "NONE", MAX_DEFBUFFER_SIZE);
 		xcvr_name = defbuffer;
 	}
-//	xcvrpref.get("xml_port", xmlport, xmlport);
 
 	loadXcvrState(xcvr_name);
 }
 
 void status::UI_laststate()
 {
+// void Fl::background2 ( uchar r, uchar g, uchar b )
+// Changes the alternative background color.
+// This color is used as a background by Fl_Input and other text widgets.
+// This call may change fl_color(FL_FOREGROUND_COLOR) if it does not provide 
+// sufficient contrast to FL_BACKGROUND2_COLOR.
+// we want to preserve the user selection.  ordering of Fl:: sequence is important
+	Fl::background2( bg2_sys_red, bg2_sys_green, bg2_sys_blue);
+	Fl::background( bg_sys_red, bg_sys_green, bg_sys_blue);
+	Fl::foreground( fg_sys_red, fg_sys_green, fg_sys_blue);
+
 	Fl_Color bgclr = fl_rgb_color(bg_red, bg_green, bg_blue);
 	Fl_Color fgclr = fl_rgb_color(fg_red, fg_green, fg_blue);
 
-	Fl::background( bg_sys_red, bg_sys_green, bg_sys_blue);
-	Fl::background2( bg2_sys_red, bg2_sys_green, bg2_sys_blue);
-	Fl::foreground( fg_sys_red, fg_sys_green, fg_sys_blue);
-
 	FreqDispA->SetCOLORS( fgclr, bgclr );
 	FreqDispA->font(fontnbr);
 	FreqDispB->SetCOLORS( fgclr, fl_color_average(bgclr, FL_BLACK, 0.87));
@@ -2098,21 +2390,21 @@ void status::UI_laststate()
 	btnALC_IDD_SWR->labelcolor(fgclr);
 
 	sldrFwdPwr->color(fl_rgb_color (pwrRed, pwrGreen, pwrBlue), bgclr);
-	sldrFwdPwr->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+	sldrFwdPwr->PeakColor(fl_rgb_color(smeter_peak_red, smeter_peak_green, smeter_peak_blue));
 
 	sldrRcvSignal->color(fl_rgb_color (smeterRed, smeterGreen, smeterBlue), bgclr);
-	sldrRcvSignal->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+	sldrRcvSignal->PeakColor(fl_rgb_color(smeter_peak_red, smeter_peak_green, smeter_peak_blue));
 
 	sldrALC->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
-	sldrALC->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+	sldrALC->PeakColor(fl_rgb_color(smeter_peak_red, smeter_peak_green, smeter_peak_blue));
 
 	sldrSWR->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
-	sldrSWR->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+	sldrSWR->PeakColor(fl_rgb_color(smeter_peak_red, smeter_peak_green, smeter_peak_blue));
 
 	sldrIDD->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
-	sldrIDD->PeakColor(fl_rgb_color (peakRed, peakGreen, peakBlue));
+	sldrIDD->PeakColor(fl_rgb_color (smeter_peak_red, smeter_peak_green, smeter_peak_blue));
 
-	sldrVoltage->color(fl_rgb_color (voltRed, voltGreen, voltBlue), bgclr);
+	sldrVoltage->color(fl_rgb_color (voltsRed, voltsGreen, voltsBlue), bgclr);
 	sldrVoltage->PeakColor(bgclr);
 
 	scaleVoltage->color(bgclr);
@@ -2121,26 +2413,26 @@ void status::UI_laststate()
 	mtr_SMETER->color(bgclr);
 	mtr_SMETER->labelcolor(fgclr);
 	sigbar_SMETER->color(fl_rgb_color (smeterRed, smeterGreen, smeterBlue), bgclr);
-	sigbar_SMETER->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+	sigbar_SMETER->PeakColor(fl_rgb_color(smeter_peak_red, smeter_peak_green, smeter_peak_blue));
 
 	mtr_PWR->color(bgclr);
 	mtr_PWR->labelcolor(fgclr);
 	sigbar_PWR->color(fl_rgb_color (pwrRed, pwrGreen, pwrBlue), bgclr);
-	sigbar_PWR->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+	sigbar_PWR->PeakColor(fl_rgb_color(smeter_peak_red, smeter_peak_green, smeter_peak_blue));
 
 	mtr_SWR->color(bgclr);
 	mtr_SWR->labelcolor(fgclr);
 	sigbar_SWR->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
-	sigbar_SWR->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+	sigbar_SWR->PeakColor(fl_rgb_color(smeter_peak_red, smeter_peak_green, smeter_peak_blue));
 
 	mtr_ALC->color(bgclr);
 	mtr_ALC->labelcolor(fgclr);
 	sigbar_ALC->color(fl_rgb_color (swrRed, swrGreen, swrBlue), bgclr);
-	sigbar_ALC->PeakColor(fl_rgb_color(peakRed, peakGreen, peakBlue));
+	sigbar_ALC->PeakColor(fl_rgb_color(smeter_peak_red, smeter_peak_green, smeter_peak_blue));
 
 	mtr_VOLTS->color(bgclr);
 	mtr_VOLTS->labelcolor(fgclr);
-	sigbar_VOLTS->color(fl_rgb_color (voltRed, voltGreen, voltBlue), bgclr);
+	sigbar_VOLTS->color(fl_rgb_color (voltsRed, voltsGreen, voltsBlue), bgclr);
 	sigbar_VOLTS->PeakColor(bgclr);
 
 // set scale for both voltage display
@@ -2264,6 +2556,9 @@ void status::UI_laststate()
 	btnUser23->label(label23.c_str()); btnUser23->redraw_label();
 	btnUser24->label(label24.c_str()); btnUser24->redraw_label();
 
+	op_yaesu_select60->selection_color(FL_BACKGROUND_COLOR);
+	op_yaesu_select60->labelcolor(FL_FOREGROUND_COLOR);
+
 	Fl::scheme(ui_scheme.c_str());
 }
 
